The below patch was taken from http://mingw-users.1079350.n2.nabble.com/Building-GREP-td7582694.html
to fix warnings like "recursive directory loop" on Windows which causes too few results.
On Windows, there are no inodes and MINGW returns always 0 as inode number.
See also https://github.com/geany/geany/issues/1229.
diff --git a/lib/same-inode.h b/lib/same-inode.h
index bf45635..410d405 100644
--- a/lib/same-inode.h
+++ b/lib/same-inode.h
@@ -24,6 +24,8 @@
      && (a).st_ino[1] == (b).st_ino[1] \
      && (a).st_ino[2] == (b).st_ino[2] \
      && (a).st_dev == (b).st_dev)
+# elif defined(__MINGW32__)
+#  define SAME_INODE(a, b) (0)
 # else
 #  define SAME_INODE(a, b)    \
     ((a).st_ino == (b).st_ino \
diff --git a/lib/fts-cycle.c b/lib/fts-cycle.c
index db617f7..d8e09bf 100644
--- a/lib/fts-cycle.c
+++ b/lib/fts-cycle.c
@@ -158,3 +158,10 @@ free_dir (FTS *sp)
   else
     free (sp->fts_cycle.state);
 }
+
+#ifdef __MINGW32__
+# define setup_dir(a)     (true)
+# define enter_dir(a,b)   (true)
+# define leave_dir(a,b)   ((void)0)
+# define free_dir(a)      ((void)0)
+#endif /* __MINGW32__ */

